@@ -1,6 +1,6 @@
 #
 # ovirt-engine-setup -- ovirt engine setup
-# Copyright (C) 2013 Red Hat, Inc.
+# Copyright (C) 2013-2015 Red Hat, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -19,34 +19,39 @@
 """Schema plugin."""
 
 
-import glob
 import datetime
-import tempfile
+import gettext
+import glob
 import os
 import shutil
-import gettext
-_ = lambda m: gettext.dgettext(message=m, domain='ovirt-engine-reports')
+import tempfile
 
 
 import libxml2
 
 
 from otopi import constants as otopicons
-from otopi import util
 from otopi import plugin
 from otopi import transaction
+from otopi import util
 
 
 from ovirt_engine import util as outil
 
 
 from ovirt_engine_setup import constants as osetupcons
-from ovirt_engine_setup.reports import constants as oreportscons
-from ovirt_engine_setup.reports import reportsutil as oreportsutil
 from ovirt_engine_setup import util as osetuputil
-from ovirt_engine_setup.engine_common import database
 from ovirt_engine_setup.engine_common \
     import constants as oengcommcons
+from ovirt_engine_setup.engine_common import database
+
+
+from ovirt_engine_setup.reports import constants as oreportscons
+from ovirt_engine_setup.reports import reportsutil as oreportsutil
+
+
+def _(m):
+    return gettext.dgettext(message=m, domain='ovirt-engine-reports')
 
 
 @util.export
@@ -91,10 +96,10 @@ class Plugin(plugin.PluginBase):
                 oreportscons.DBEnv.NEW_DATABASE
             ]:
                 self._backup = self._dbovirtutils.backup(
-                    dir=(
-                        oreportscons.FileLocations.
+                    dir=self._parent.environment[
+                        oreportscons.ConfigEnv.
                         OVIRT_ENGINE_REPORTS_DB_BACKUP_DIR
-                    ),
+                    ],
                     prefix=(
                         oreportscons.Const.
                         OVIRT_ENGINE_REPORTS_DB_BACKUP_PREFIX
@@ -164,8 +169,16 @@ class Plugin(plugin.PluginBase):
                 if entry['dst'] is not None and os.path.exists(entry['dst']):
                     shutil.rmtree(entry['dst'])
 
+    def _check_master_props(self):
+        conf = (
+            oreportscons.FileLocations.
+            OVIRT_ENGINE_REPORTS_BUILDOMATIC_DBPROP
+        )
+        self.logger.debug('conf %s found: %s' % (conf, os.path.exists(conf)))
+
     def _buildJs(self, cmd, config, noSuffix=False):
 
+        self._check_master_props()
         try:
             myumask = os.umask(0o022)
 
@@ -232,6 +245,7 @@ class Plugin(plugin.PluginBase):
                     ),
                     0o700,
                 )
+        self._check_master_props()
 
     def _workaroundUsersNullPaswords(self, src):
         for f in glob.glob(os.path.join(src, 'users', '*.xml')):
@@ -310,70 +324,50 @@ class Plugin(plugin.PluginBase):
             'data_sources',
             'ovirt.xml',
         )
-        if self._dwhdatasource:
-            shutil.copyfile(
-                self._dwhdatasource,
-                dwhdatasource,
-            )
-            if (
-                self.environment[oreportscons.JasperEnv.JASPER_NAME] == 'pro'
-            ):
-                with oreportsutil.XMLDoc(dwhdatasource) as xml:
-                    node = xml.xpath.xpathEval('/jdbcDataSource/folder')[0]
-                    nodeContent = node.getContent()
-                    nodeContent = nodeContent.replace(
-                        os.path.join(
-                            '/',
-                            self._reportsProRelativePath,
-                        ),
-                        ''
-                    )
-                    node.setContent(nodeContent)
-        else:
-            with oreportsutil.XMLDoc(dwhdatasource) as xml:
-                xml.setNodesContent(
-                    '/jdbcDataSource/connectionUrl',
-                    'jdbc:postgresql://%s:%s/%s?%s' % (
-                        self.environment[
-                            oreportscons.DWHDBEnv.HOST
-                        ],
-                        self.environment[
-                            oreportscons.DWHDBEnv.PORT
-                        ],
-                        self.environment[
-                            oreportscons.DWHDBEnv.DATABASE
-                        ],
-                        '&'.join(
-                            s for s in (
-                                'ssl=true'
-                                if self.environment[
-                                    oreportscons.DWHDBEnv.SECURED
-                                ] else '',
+        with oreportsutil.XMLDoc(dwhdatasource) as xml:
+            xml.setNodesContent(
+                '/jdbcDataSource/connectionUrl',
+                'jdbc:postgresql://%s:%s/%s?%s' % (
+                    self.environment[
+                        oreportscons.DWHDBEnv.HOST
+                    ],
+                    self.environment[
+                        oreportscons.DWHDBEnv.PORT
+                    ],
+                    self.environment[
+                        oreportscons.DWHDBEnv.DATABASE
+                    ],
+                    '&'.join(
+                        s for s in (
+                            'ssl=true'
+                            if self.environment[
+                                oreportscons.DWHDBEnv.SECURED
+                            ] else '',
 
-                                (
-                                    'sslfactory='
-                                    'org.postgresql.ssl.NonValidatingFactory'
-                                )
-                                if not self.environment[
-                                    oreportscons.DWHDBEnv.
-                                    SECURED_HOST_VALIDATION
-                                ] else ''
-                            ) if s
-                        ),
+                            (
+                                'sslfactory='
+                                'org.postgresql.ssl.NonValidatingFactory'
+                            )
+                            if not self.environment[
+                                oreportscons.DWHDBEnv.
+                                SECURED_HOST_VALIDATION
+                            ] else ''
+                        ) if s
                     ),
-                )
-                xml.setNodesContent(
-                    '/jdbcDataSource/connectionUser',
-                    self.environment[
-                        oreportscons.DWHDBEnv.USER
-                    ],
-                )
-                xml.setNodesContent(
-                    '/jdbcDataSource/connectionPassword',
-                    self.environment[
-                        oreportscons.DWHDBEnv.PASSWORD
-                    ],
-                )
+                ),
+            )
+            xml.setNodesContent(
+                '/jdbcDataSource/connectionUser',
+                self.environment[
+                    oreportscons.DWHDBEnv.USER
+                ],
+            )
+            xml.setNodesContent(
+                '/jdbcDataSource/connectionPassword',
+                self.environment[
+                    oreportscons.DWHDBEnv.PASSWORD
+                ],
+            )
 
         return reportsImport
 
@@ -430,7 +424,6 @@ class Plugin(plugin.PluginBase):
         self._quartzprops = None
         self._users = None
         self._jobs = None
-        self._dwhdatasource = None
         self._savedReports = None
         self._reportsProRelativePath = ''
 
@@ -508,34 +501,15 @@ class Plugin(plugin.PluginBase):
                 )
 
     @plugin.event(
-        stage=plugin.Stages.STAGE_MISC,
+        stage=plugin.Stages.STAGE_EARLY_MISC,
         name=oreportscons.Stages.JASPER_NAME_SET,
         condition=lambda self: self.environment[oreportscons.CoreEnv.ENABLE],
     )
     def _jasper_name(self):
-        install = glob.glob(
-            os.path.join(
-                self.environment[oreportscons.ConfigEnv.JASPER_HOME],
-                'buildomatic',
-                'conf_source',
-                'ie*',
-            )
-        )
-        if len(install) != 1:
-            raise RuntimeError(
-                _(
-                    'Unexpected jasper installation, '
-                    'buildomatic lib folder is missing'
-                )
-            )
-        self.environment[
-            oreportscons.JasperEnv.JASPER_NAME
-        ] = os.path.basename(install[0]).replace(
-            'ie', ''
-        ).lower()
+        self._oreportsutil.set_jasper_name()
 
     @plugin.event(
-        stage=plugin.Stages.STAGE_MISC,
+        stage=plugin.Stages.STAGE_EARLY_MISC,
         name=oreportscons.Stages.JASPER_DEPLOY_EXPORT,
         condition=lambda self: (
             self.environment[oreportscons.CoreEnv.ENABLE] and
@@ -550,23 +524,23 @@ class Plugin(plugin.PluginBase):
     )
     def _export(self):
         config = self._jasperConfiguration()
-        self._quartzprops = os.path.join(self._temproot, 'quartzprops')
 
         if (
             os.path.exists(
                 oreportscons.FileLocations.OVIRT_ENGINE_REPORTS_JASPER_WAR
             )
         ):
-            shutil.copyfile(
+            with open(
                 oreportscons.FileLocations.OVIRT_ENGINE_REPORTS_JASPER_QUARTZ,
-                self._quartzprops,
-            )
+                'r'
+            ) as f:
+                self._quartzprops = f.read().splitlines()
         elif (
             os.path.exists(
                 self.environment[oreportscons.ConfigEnv.LEGACY_REPORTS_WAR]
             )
         ):
-            shutil.copyfile(
+            with open(
                 os.path.join(
                     self.environment[
                         oreportscons.ConfigEnv.LEGACY_REPORTS_WAR
@@ -574,8 +548,9 @@ class Plugin(plugin.PluginBase):
                     'WEB-INF',
                     'js.quartz.properties'
                 ),
-                self._quartzprops,
-            )
+                'r'
+            ) as f:
+                self._quartzprops = f.read().splitlines()
 
         else:
             raise RuntimeError(
@@ -638,33 +613,6 @@ class Plugin(plugin.PluginBase):
                 '--roles',
             ),
         )
-        dwhdatasourceexport = self._oreportsutil.jsexport(
-            what='dwhdatasourceexport',
-            args=(
-                '--uris',
-                os.path.join(
-                    '/',
-                    self._reportsProRelativePath,
-                    'reports_resources',
-                    'JDBC',
-                    'data_sources',
-                    'ovirt',
-                ),
-            ),
-        )
-        #
-        # due to os.path.join considering any path starting with '/'
-        # to be a new absulote path, had to concat the path strings.
-        #
-        self._dwhdatasource = os.path.join(
-            dwhdatasourceexport,
-            'resources',
-            self._reportsProRelativePath,
-            'reports_resources',
-            'JDBC',
-            'data_sources',
-            'ovirt.xml',
-        )
 
         self._workaroundUsersNullPaswords(self._users)
 
@@ -725,6 +673,12 @@ class Plugin(plugin.PluginBase):
             )
         )
 
+    QUARTZ_NEEDED_PROPS = {
+        'report.quartz.misfirepolicy.singlesimplejob': 'SMART_POLICY',
+        'report.quartz.misfirepolicy.repeatingsimplejob': 'SMART_POLICY',
+        'report.quartz.misfirepolicy.calendarjob': 'SMART_POLICY',
+    }
+
     @plugin.event(
         stage=plugin.Stages.STAGE_MISC,
         name=oreportscons.Stages.JASPER_DEPLOY_IMPORT,
@@ -739,10 +693,22 @@ class Plugin(plugin.PluginBase):
         self.logger.info(_('Importing data into Jasper'))
 
         if self._quartzprops:
-            shutil.copyfile(
-                self._quartzprops,
+            with open(
                 oreportscons.FileLocations.OVIRT_ENGINE_REPORTS_JASPER_QUARTZ,
-            )
+                'w'
+            ) as f:
+                f.write(
+                    '\n'.join(
+                        osetuputil.editConfigContent(
+                            content=self._quartzprops,
+                            params=self.QUARTZ_NEEDED_PROPS,
+                            keep_existing=True,
+                            param_re='(\w|\.)+',
+                            new_line_tpl='{spaces}{param}={value}',
+                        )
+                    )
+                )
+
             os.chmod(
                 oreportscons.FileLocations.OVIRT_ENGINE_REPORTS_JASPER_QUARTZ,
                 0o644,
