@@ -1,6 +1,6 @@
 #
 # ovirt-engine-setup -- ovirt engine setup
-# Copyright (C) 2013 Red Hat, Inc.
+# Copyright (C) 2013-2015 Red Hat, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -20,17 +20,24 @@
 
 
 import gettext
-_ = lambda m: gettext.dgettext(message=m, domain='ovirt-engine-reports')
 
 
-from otopi import util
 from otopi import plugin
+from otopi import util
 
 
 from ovirt_engine_setup import constants as osetupcons
-from ovirt_engine_setup import reportsconstants as oreportscons
 from ovirt_engine_setup import dialog
-from ovirt_engine_setup import postgres
+from ovirt_engine_setup.engine_common \
+    import constants as oengcommcons
+from ovirt_engine_setup.engine_common import postgres
+
+
+from ovirt_engine_setup.reports import constants as oreportscons
+
+
+def _(m):
+    return gettext.dgettext(message=m, domain='ovirt-engine-reports')
 
 
 @util.export
@@ -87,11 +94,11 @@ class Plugin(plugin.PluginBase):
     @plugin.event(
         stage=plugin.Stages.STAGE_CUSTOMIZATION,
         before=(
-            osetupcons.Stages.DIALOG_TITLES_E_DATABASE,
+            oengcommcons.Stages.DIALOG_TITLES_E_DATABASE,
             oreportscons.Stages.DB_CONNECTION_CUSTOMIZATION,
         ),
         after=(
-            osetupcons.Stages.DIALOG_TITLES_S_DATABASE,
+            oengcommcons.Stages.DIALOG_TITLES_S_DATABASE,
             oreportscons.Stages.CORE_ENABLE,
         ),
         condition=lambda self: self._enabled,
@@ -152,14 +159,14 @@ class Plugin(plugin.PluginBase):
         stage=plugin.Stages.STAGE_CUSTOMIZATION,
         priority=plugin.Stages.PRIORITY_LAST,
         condition=lambda self: self.environment[
-            osetupcons.DBEnv.HOST
+            oreportscons.DBEnv.HOST
         ] == 'localhost',
     )
     def _customization_firewall(self):
         self.environment[osetupcons.NetEnv.FIREWALLD_SERVICES].extend([
             {
                 'name': 'ovirt-postgres',
-                'directory': 'ovirt-engine'
+                'directory': 'ovirt-common'
             },
         ])
 
